@@ -1,7 +1,7 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2003-2008 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2003-2009 aMule Team ( admin@amule.org / http://www.amule.org )
 // Copyright (c) 2002 Merkur ( devs@emule-project.net / http://www.emule-project.net )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
@@ -43,6 +43,7 @@
 #include "Preferences.h"
 #include "updownclient.h"
 #include "UploadQueue.h"
+#include "TransferWnd.h"	// Needed for UpdateBottomPaneTitle
 
 #include <wx/menu.h>
 #include <wx/textdlg.h>
@@ -206,6 +207,10 @@ void CClientListCtrl::SetListView( ViewType newView )
 		if (newView != vtNone) {
 			LoadSettings();
 		}
+
+		if (theApp->amuledlg) {
+			theApp->amuledlg->m_transferwnd->UpdateBottomPaneTitle(newView);
+		}
 	}
 }
 
