@@ -1,7 +1,7 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2003-2005 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2003-2009 aMule Team ( admin@amule.org / http://www.amule.org )
 // Copyright (c) 2002 Merkur ( devs@emule-project.net / http://www.emule-project.net )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
@@ -20,20 +20,19 @@
 // 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA, 02111-1307, USA
+// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA
 //
 
 #ifndef SEARCHLISTCTRL_H
 #define SEARCHLISTCTRL_H
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "SearchListCtrl.h"
-#endif
 
-#include <list>				// Needed for std::list
+#include "wx/colour.h"		// Needed for wxColour
+#include <wx/regex.h>		// Needed for wxRegExp
 
 #include "MuleListCtrl.h"	// Needed for CMuleListCtrl
 
+
 class CSearchList;
 class CSearchFile;
 
@@ -72,7 +71,6 @@ public:
 	 */
 	virtual ~CSearchListCtrl();
 
-
 	/**
 	 * Adds ths specified file to the list.
 	 *
@@ -85,6 +83,11 @@ public:
 	 */
 	void	AddResult(CSearchFile* toshow);
 
+	/**
+	 * Removes the specified file from the list.
+	 */
+	void	RemoveResult(CSearchFile* toshow);
+	
 	/**
 	 * Updates the specified source.
 	 *
@@ -99,42 +102,97 @@ public:
 	 */
 	void	ShowResults( long ResultsId );
 
-
 	/**
-	 * Updates the colors of item at the specified index. 
+	 * Updates the colors of item at the specified index.
 	 *
-	 * @param index The zero-based index of the item. 
+	 * @param index The zero-based index of the item.
 	 *
-	 * This function sets the color of the item based on the following:
+	 * This function returns the color of the item based on the following:
 	 *  - Downloading files are marked in red.
 	 *  - Known (shared/completed) files are marked in green.
 	 *  - New files are marked in blue depending on the number of sources.
 	 */
-	void	UpdateColor( long index );
+	void UpdateItemColor(long index);
 
+	/**
+	 * Updates the colors of all assosiated items, which means parents and/or siblings.
+	 */
+	void UpdateAllRelativesColor(CSearchFile *file, long index);
 
 	/**
 	 * Returns the current Search Id. 
 	 *
 	 * @return The Search Id of the displayed results (set through ShowResults()).
 	 */
-	long	GetSearchId();
+	wxUIntPtr	GetSearchId();
+	
+	/**
+	 * Sets the filter which decides which results should be shown.
+	 *
+	 * @param regExp A regular expression targeting the filenames.
+	 * @param invert If true, invert the results of the filter-test.
+	 * @param filterKnown Should files that are queued or known be filtered out.
+	 *
+	 * An invalid regExp will result in all results being displayed.
+	 */
+	void	SetFilter(const wxString& regExp, bool invert, bool filterKnown);
+
+	/**
+	 * Toggels the use of filtering on and off.
+	 */
+	void	EnableFiltering(bool enabled);
+	
+	/**
+	 * Returns the number of items hidden due to filtering.
+	 */
+	size_t	GetHiddenItemCount() const;
+	
+	/**
+	 * Attempts to download all selected items, updating color-scheme as needed.
+	 *
+	 * @param category The target category, or -1 to use the drop-down selection.
+	 */
+	void	DownloadSelected(int category = -1);	
 	
 protected:
+	typedef std::list<CSearchFile*> ResultList;
 
+	//! List used to store results that are hidden due to matching the filter.
+	ResultList	m_filteredOut;
+
+	//! The current filter reg-exp.
+	wxRegEx		m_filter;
+
+	//! The text from which the filter is compiled.
+	wxString	m_filterText;
+
+	//! Controls if shared/queued results should be shown.
+	bool		m_filterKnown;
+	
+	//! Controls if the result of filter-hits should be inverted
+	bool		m_invert;
+
+	//! Specifies if filtering should be used
+	bool		m_filterEnabled;
+
+	/**
+	 * Returns true if the filename is filtered.
+	 */
+	bool	IsFiltered(const CSearchFile* file);
+	
 	/**
 	 * Sorter function used by wxListCtrl::SortItems function.
 	 *
 	 * @see CMuleListCtrl::SetSortFunc
 	 * @see wxListCtrl::SortItems
 	 */
-	static int wxCALLBACK SortProc( long item1, long item2, long sortData );
+	static int wxCALLBACK SortProc(wxUIntPtr item1, wxUIntPtr item2, long sortData);
 
-	/**
-	 * Override default AltSortAllowed method . See CMuleListCtrl.cpp.
-	 */
-	virtual bool AltSortAllowed( int column );
+	/** @see CMuleListCtrl::AltSortAllowed */
+	virtual bool AltSortAllowed(unsigned column) const;
 
+	/** @see CMuleListCtrl::GetTTSText */
+	virtual wxString GetTTSText(unsigned item) const;
 
 	/**
 	 * Helper function which syncs two lists.
@@ -162,19 +220,25 @@ protected:
 	 * the src argument as the src argument of the SyncLists function.
 	 */
 	static void SyncOtherLists( CSearchListCtrl* src );
-
 	
 	//! This list contains pointers to all current instances of CSearchListCtrl.
 	static std::list<CSearchListCtrl*> s_lists;
 	
 	//! The ID of the search-results which the list is displaying or zero if unset. 
-	long	m_nResultsID;
+	wxUIntPtr m_nResultsID;
 
+	//! Custom drawing, needed to display children of search-results.
+	void OnDrawItem(int item, wxDC* dc, const wxRect& rect, const wxRect& rectHL, bool highlighted);
+
+	/**
+	 * Removes or adds child-entries for the given file.
+	 */
+	void ShowChildren(CSearchFile* file, bool show);
 
 	/**
 	 * Event handler for right mouse clicks.
 	 */
-	void OnRightClick( wxMouseEvent& event );
+	void OnRightClick( wxListEvent& event );
 
 	/**
 	 * Event handler for double-clicks or enter.
@@ -194,23 +258,27 @@ protected:
 	 * This eventhandler takes care of sync'ing all the other lists with this one.
 	 */
 	void OnColumnResize( wxListEvent& event );
-
 	
 	/**
 	 * Event handler for get-url menu items.
 	 */
 	void OnPopupGetUrl( wxCommandEvent& event );
 
-	/**
-	 * Event handler for fake-check menu items.
-	 */
-	void OnPopupFakeCheck( wxCommandEvent& event );
-
 	/**
 	 * Event handler for Razorback 2 stats menu items.
 	 */
 	void OnRazorStatsCheck( wxCommandEvent& event );
 
+	/**
+	 * Event handler for related search.
+	 */
+	void OnRelatedSearch( wxCommandEvent& event );
+
+	/**
+	 * Event handler for "mark as known".
+	 */
+	void OnMarkAsKnown( wxCommandEvent& event );
+
 	/**
 	 * Event handler for download-file(s) menu item.
 	 */
@@ -220,3 +288,4 @@ protected:
 };
 
 #endif // SEARCHLISTCTRL_H
+// File_checked_for_headers
