@@ -1,7 +1,7 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2003-2008 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2003-2009 aMule Team ( admin@amule.org / http://www.amule.org )
 // Copyright (c) 2002 Merkur ( devs@emule-project.net / http://www.emule-project.net )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
@@ -509,7 +509,11 @@ CServerConnect::CServerConnect(CServerList* in_serverlist, amuleIPV4Address &add
 	singleconnecting = false;
 
 	// initalize socket for udp packets
-	serverudpsocket = new CServerUDPSocket(address, thePrefs::GetProxyData());
+	if (thePrefs::GetNetworkED2K()) {
+		serverudpsocket = new CServerUDPSocket(address, thePrefs::GetProxyData());
+	} else {
+		serverudpsocket = NULL;
+	}
 }
 
 
