@@ -1,8 +1,8 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2004-2008 Angel Vidal (Kry) ( kry@amule.org )
-// Copyright (c) 2004-2008 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2004-2009 Angel Vidal (Kry) ( kry@amule.org )
+// Copyright (c) 2004-2009 aMule Team ( admin@amule.org / http://www.amule.org )
 // Copyright (c) 2003 Barry Dunne (http://www.emule-project.net)
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
@@ -253,16 +253,21 @@ void CSearch::ProcessResponse(uint32_t fromIP, uint16_t fromPort, ContactList *r
 {
 	AddDebugLogLineM(false, logKadSearch, wxT("Processing search response from ") + Uint32_16toStringIP_Port(wxUINT32_SWAP_ALWAYS(fromIP), fromPort));
 
-	if (results) {
-		m_lastResponse = time(NULL);
-	}
-
 	ContactList::iterator response;
 	// Remember the contacts to be deleted when finished
 	for (response = results->begin(); response != results->end(); ++response) {
 		m_delete.push_back(*response);
 	}
 
+	// Make sure the node is not sending more results than we requested, which is not only a protocol violation
+	// but most likely a malicious answer
+	if (results->size() > GetRequestContactCount()) {
+		AddDebugLogLineM(false, logKadSearch, wxT("Node ") + Uint32toStringIP(wxUINT32_SWAP_ALWAYS(fromIP)) + wxT(" sent more contacts than requested on a routing query, ignoring response"));
+		return;
+	}
+
+	m_lastResponse = time(NULL);
+
 	if (m_type == NODEFWCHECKUDP) {
 		m_answers++;
 		delete results;
@@ -289,6 +294,11 @@ void CSearch::ProcessResponse(uint32_t fromIP, uint16_t fromPort, ContactList *r
 			// Add to list of people who responded
 			m_responded[fromDistance] = from;
 
+			std::map<uint32_t, uint32_t> mapReceivedIPs;
+			std::map<uint32_t, uint32_t> mapReceivedSubnets;
+			// A node is not allowed to answer with contacts to itself
+			mapReceivedIPs[fromIP] = 1;
+			mapReceivedSubnets[fromIP & 0xFFFFFF00] = 1;
 			// Loop through their responses
 			for (response = results->begin(); response != results->end(); ++response) {
 				CContact *c = *response;
@@ -296,14 +306,36 @@ void CSearch::ProcessResponse(uint32_t fromIP, uint16_t fromPort, ContactList *r
 
 				// Ignore this contact if already known or tried it.
 				if (m_possible.count(distance) > 0) {
-					// AddDebugLogLineM(false, logKadSearch, wxT("Search result from already known client: ignore"));
+					AddDebugLogLineM(false, logKadSearch, wxT("Search result from already known client: ignore"));
 					continue;
 				}
 				if (m_tried.count(distance) > 0) {
-					// AddDebugLogLineM(false, logKadSearch, wxT("Search result from already tried client: ignore"));
+					AddDebugLogLineM(false, logKadSearch, wxT("Search result from already tried client: ignore"));
 					continue;
 				}
 
+				// We only accept unique IPs in the answer, having multiple IDs pointing to one IP in the routing tables
+				// is no longer allowed since eMule0.49a, aMule-2.2.1 anyway
+				if (mapReceivedIPs.count(c->GetIPAddress()) > 0) {
+					AddDebugLogLineM(false, logKadSearch, wxT("Multiple KadIDs pointing to same IP (") + Uint32toStringIP(wxUINT32_SWAP_ALWAYS(c->GetIPAddress())) + wxT(") in Kad(2)Res answer - ignored, sent by ") + Uint32toStringIP(wxUINT32_SWAP_ALWAYS(from->GetIPAddress())));
+					continue;
+				} else {
+					mapReceivedIPs[c->GetIPAddress()] = 1;
+				}
+				// and no more than 2 IPs from the same /24 subnet
+				if (mapReceivedSubnets.count(c->GetIPAddress() & 0xFFFFFF00) > 0 && !::IsLanIP(wxUINT32_SWAP_ALWAYS(c->GetIPAddress()))) {
+					wxASSERT(mapReceivedSubnets.find(c->GetIPAddress() & 0xFFFFFF00) != mapReceivedSubnets.end());
+					int subnetCount = mapReceivedSubnets.find(c->GetIPAddress() & 0xFFFFFF00)->second;
+					if (subnetCount >= 2) {
+						AddDebugLogLineM(false, logKadSearch, wxT("More than 2 KadIDs pointing to same subnet (") + Uint32toStringIP(wxUINT32_SWAP_ALWAYS(c->GetIPAddress() & 0xFFFFFF00)) + wxT("/24) in Kad(2)Res answer - ignored, sent by ") + Uint32toStringIP(wxUINT32_SWAP_ALWAYS(from->GetIPAddress())));
+						continue;
+					} else {
+						mapReceivedSubnets[c->GetIPAddress() & 0xFFFFFF00] = subnetCount + 1;
+					}
+				} else {
+					mapReceivedSubnets[c->GetIPAddress() & 0xFFFFFF00] = 1;
+				}
+
 				// Add to possible
 				m_possible[distance] = c;
 
@@ -782,8 +814,8 @@ void CSearch::ProcessResultFile(const CUInt128& answer, TagPtrList *info)
 	uint32_t ip = 0;
 	uint16_t tcp = 0;
 	uint16_t udp = 0;
-	uint32_t serverip = 0;
-	uint16_t serverport = 0;
+	uint32_t buddyip = 0;
+	uint16_t buddyport = 0;
 	uint8_t byCryptOptions = 0; // 0 = not supported.
 	CUInt128 buddy;
 
@@ -798,9 +830,9 @@ void CSearch::ProcessResultFile(const CUInt128& answer, TagPtrList *info)
 		} else if (!tag->GetName().Cmp(TAG_SOURCEUPORT)) {
 			udp = tag->GetInt();
 		} else if (!tag->GetName().Cmp((TAG_SERVERIP))) {
-			serverip = tag->GetInt();
+			buddyip = tag->GetInt();
 		} else if (!tag->GetName().Cmp(TAG_SERVERPORT)) {
-			serverport = tag->GetInt();
+			buddyport = tag->GetInt();
 		} else if (!tag->GetName().Cmp(TAG_BUDDYHASH)) {
 			CMD4Hash hash;
 			// TODO: Error handling
@@ -827,7 +859,7 @@ void CSearch::ProcessResultFile(const CUInt128& answer, TagPtrList *info)
 		case 6:
 			AddDebugLogLineM(false, logKadSearch, wxString::Format(wxT("Trying to add a source type %i, ip "), type) + Uint32_16toStringIP_Port(wxUINT32_SWAP_ALWAYS(ip), udp));
 			m_answers++;
-			theApp->downloadqueue->KademliaSearchFile(m_searchID, &answer, &buddy, type, ip, tcp, udp, serverip, serverport, byCryptOptions);
+			theApp->downloadqueue->KademliaSearchFile(m_searchID, &answer, &buddy, type, ip, tcp, udp, buddyip, buddyport, byCryptOptions);
 			break;
 		case 2: 
 			//Don't use this type, some clients will process it wrong.
@@ -1020,28 +1052,11 @@ void CSearch::SendFindValue(CContact *contact)
 
 		CMemFile packetdata(33);
 		// The number of returned contacts is based on the type of search.
-		switch(m_type){
-			case NODE:
-			case NODECOMPLETE:
-			case NODESPECIAL:
-			case NODEFWCHECKUDP:
-				packetdata.WriteUInt8(KADEMLIA_FIND_NODE);
-				break;
-			case FILE:
-			case KEYWORD:
-			case FINDSOURCE:
-			case NOTES:
-				packetdata.WriteUInt8(KADEMLIA_FIND_VALUE);
-				break;
-			case FINDBUDDY:
-			case STOREFILE:
-			case STOREKEYWORD:
-			case STORENOTES:
-				packetdata.WriteUInt8(KADEMLIA_STORE);
-				break;
-			default:
-				AddDebugLogLineM(false, logKadSearch, wxT("Invalid search type. (CSearch::sendFindValue)"));
-				return;
+		uint8_t contactCount = GetRequestContactCount();
+		if (contactCount > 0) {
+			packetdata.WriteUInt8(contactCount);
+		} else {
+			return;
 		}
 		// Put the target we want into the packet.
 		packetdata.WriteUInt128(m_target);
@@ -1212,7 +1227,7 @@ void CSearch::PreparePacketForTags(CMemFile *bio, CKnownFile *file)
 			bio->WriteTagPtrList(taglist);
 		} else {
 			//If we get here.. Bad things happen.. Will fix this later if it is a real issue.
-			wxASSERT(0);
+			wxFAIL;
 		}
 	} catch (const CEOFException& err) {
 		AddDebugLogLineM(true, logKadSearch, wxT("CEOFException in CSearch::PreparePacketForTags: ") + err.what());
@@ -1233,4 +1248,29 @@ void CSearch::SetSearchTermData(uint32_t searchTermsDataSize, const uint8_t *sea
 	m_searchTermsData = new uint8_t [searchTermsDataSize];
 	memcpy(m_searchTermsData, searchTermsData, searchTermsDataSize);
 }
-// File_checked_for_headers
+
+uint8_t CSearch::GetRequestContactCount() const throw()
+{
+	// Returns the amount of contacts we request on routing queries based on the search type
+	switch (m_type) {
+		case NODE:
+		case NODECOMPLETE:
+		case NODESPECIAL:
+		case NODEFWCHECKUDP:
+			return KADEMLIA_FIND_NODE;
+		case FILE:
+		case KEYWORD:
+		case FINDSOURCE:
+		case NOTES:
+			return KADEMLIA_FIND_VALUE;
+		case FINDBUDDY:
+		case STOREFILE:
+		case STOREKEYWORD:
+		case STORENOTES:
+			return KADEMLIA_STORE;
+		default:
+			AddDebugLogLineM(false, logKadSearch, wxT("Invalid search type. (CSearch::GetRequestContactCount())"));
+			wxFAIL;
+			return 0;
+	}
+}
