@@ -1,7 +1,7 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2003-2008 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2003-2009 aMule Team ( admin@amule.org / http://www.amule.org )
 // Copyright (c) 2002 Merkur ( devs@emule-project.net / http://www.emule-project.net )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
@@ -93,7 +93,8 @@ enum ESourceFrom {
 	SF_SOURCE_EXCHANGE,
 	SF_PASSIVE,
 	SF_LINK,
-	SF_SOURCE_SEEDS
+	SF_SOURCE_SEEDS,
+	SF_SEARCH_RESULT
 };
 
 enum ESecureIdentState{
@@ -781,8 +782,8 @@ private:
 	std::list<Pending_Block_Struct*>	m_PendingBlocks_list;
 	std::list<Requested_Block_Struct*>	m_DownloadBlocks_list;
 
+	// download speed calculation
 	float		kBpsDown;
-	float		fDownAvgFilter;
 	uint32		msReceivedPrev;
 	uint32		bytesReceivedCycle;
 	// chat
