@@ -1,8 +1,8 @@
 //
 // This file is part of the aMule Project.
 //
-// Copyright (c) 2003-2008 Kry ( elkry@users.sourceforge.net / http://www.amule.org )
-// Copyright (c) 2003-2008 aMule Team ( admin@amule.org / http://www.amule.org )
+// Copyright (c) 2003-2009 Kry ( elkry@users.sourceforge.net / http://www.amule.org )
+// Copyright (c) 2003-2009 aMule Team ( admin@amule.org / http://www.amule.org )
 // Copyright (c) 2002 Merkur ( devs@emule-project.net / http://www.emule-project.net )
 //
 // Any parts of this program derived from the xMule, lMule or eMule project,
@@ -36,7 +36,9 @@
 #include "RLE.h"
 #include "OtherStructs.h"
 
-#include "UPnP.h"
+#ifdef ENABLE_UPNP
+#	include "UPnPBase.h"
+#endif
 
 #include <wx/datetime.h>  // For DownloadFile::wxtLastSeenComplete
 
